# Simplifying SQLAlchemy
## By Arcader
### Compatible with none currently
### Building compatibility for SQLite's section of SQLAlchemy
# You can import my package by `pip install SSQLA`


- I found SQLAlchemy to difficult to try to understand, so I will understand it and make it easier



## Roadmap

- v0.4-alpha - I plan to finish functionality for the createTable function and the createColumn function
- v0.5-alpha - I plan to add functionality for basic sql statements like INSERT, UPDATE, and POP.

***

## Links
[PyPi Page](https://pypi.org/project/SSQLA)

[SSQLA Testing Grounds (On replit)](https://replit.com/@Arcader717/SSQLA-Testing-Grounds)

